@@ -17,17 +17,16 @@ require AutoLoader;
 );
 @EXPORT_OK = ();
 
-$VERSION = '0.10';
+$VERSION = '0.11';
 
 bootstrap ShiftJIS::CP932::MapUTF $VERSION;
 
 1;
 __END__
 
-
 =head1 NAME
 
-ShiftJIS::CP932::MapUTF - Conversion between Microsoft CP-932 and Unicode
+ShiftJIS::CP932::MapUTF - Conversion between Microsoft Windows CP-932 and Unicode
 
 =head1 SYNOPSIS
 
@@ -37,7 +36,7 @@ ShiftJIS::CP932::MapUTF - Conversion between Microsoft CP-932 and Unicode
 
 =head1 DESCRIPTION
 
-The Microsoft CodePage 932 (CP-932) table comprises 7915 characters:
+The Microsoft Windows CodePage 932 (CP-932) table comprises 7915 characters:
 
   JIS X 0201-1976 single-byte characters (191 characters),
   JIS X 0208-1990 double-byte characters (6879 characters),
@@ -53,7 +52,7 @@ For example, there are two characters that are mapped to U+2252,
 namely, 0x81e0 (JIS X 0208) and 0x8790 (NEC special character).
 
 This module provides some functions to maps
-from CP-932 to Unicode, and vice versa. 
+from Windows CP-932 to Unicode, and vice versa. 
 
 =over 4
 
@@ -61,14 +60,16 @@ from CP-932 to Unicode, and vice versa.
 
 =item C<cp932_to_unicode(CODEREF, STRING)>
 
-Converts CP-932 to Unicode (UTF-8/UTF-EBCDIC as a Unicode-oriented perl knows).
+Converts Windows CP-932 to Unicode
+(UTF-8/UTF-EBCDIC as a Unicode-oriented perl knows).
 
 For example, converts C<\x81\xe0> or C<\x87\x90> to C<U+2252>
 in the Unicode.
 
-Characters unmapped to Unicode, if C<CODEREF> is not specified, are deleted;
-if C<CODEREF> is specified, 
-converted using C<CODEREF> from the CP-932 character string.
+Characters unmapped to Unicode are deleted,
+if C<CODEREF> is not specified;
+otherwise, converted using the C<CODEREF>
+from the Windows CP-932 character string.
 
 For example, converts C<\x82\xf2> to C<U+3094>, C<HIRAGANA LETTER VU>,
 in the Unicode.
@@ -82,20 +83,21 @@ in the Unicode.
 
 =item C<cp932_to_utf16be(CODEREF, STRING)>
 
-Converts CP-932 to UTF-16BE.
+Converts Windows CP-932 to UTF-16BE.
 
 =item C<cp932_to_utf16le(STRING)>
 
 =item C<cp932_to_utf16le(CODEREF, STRING)>
 
-Converts CP-932 to UTF-16LE.
+Converts Windows CP-932 to UTF-16LE.
 
 For example, converts C<\x81\xe0> or C<\x87\x90> to C<U+2252>
 in the UTF-16LE encoding.
 
-Characters unmapped to Unicode, if C<CODEREF> is not specified, are deleted;
-if C<CODEREF> is specified,
-converted using C<CODEREF> from the CP-932 character string.
+Characters unmapped to Unicode are deleted,
+if C<CODEREF> is not specified;
+otherwise, converted using the C<CODEREF>
+from the Windows CP-932 character string.
 
 For example, converts C<\x82\xf2> to C<U+3094>, C<HIRAGANA LETTER VU>,
 in the UTF-16LE encoding.
@@ -110,16 +112,16 @@ in the UTF-16LE encoding.
 =item C<unicode_to_cp932(CODEREF, STRING)>
 
 Converts Unicode (UTF-8/UTF-EBCDIC as a Unicode-oriented perl knows) 
-to CP-932 (normalized).
+to Windows CP-932 (normalized).
 
 For example, C<U+2252> in the Unicode is converted
 to C<\x81\xe0>, not to C<\x87\x90>.
 
-Characters unmapped to CP-932, if C<CODEREF> is not specified, are deleted;
-if C<CODEREF> is specified, 
-converted using C<CODEREF> from its Unicode codepoint (integer).
+Characters unmapped to Windows CP-932 are deleted,
+if C<CODEREF> is not specified;
+otherwise, converted using the C<CODEREF> from its Unicode codepoint (integer).
 
-For example, characters unmapped to CP-932 are 
+For example, characters unmapped to Windows CP-932 are 
 converted to numerical character references for HTML 4.01.
 
     unicode_to_cp932(sub {sprintf "&#x%04x;", shift}, $unicode_string);
@@ -128,22 +130,22 @@ converted to numerical character references for HTML 4.01.
 
 =item C<utf16be_to_cp932(CODEREF, STRING)>
 
-Converts C<UTF-16BE> to C<CP-932> (normalized).
+Converts UTF-16BE to Windows CP-932 (normalized).
 
 =item C<utf16le_to_cp932(STRING)>
 
 =item C<utf16le_to_cp932(CODEREF, STRING)>
 
-Converts C<UTF-16LE> to C<CP-932> (normalized).
+Converts UTF-16LE to Windows CP-932 (normalized).
 
-For example, C<U+2252> in the C<UTF-16LE> encoding is converted
+For example, C<U+2252> in the UTF-16LE encoding is converted
 to C<\x81\xe0>, not to C<\x87\x90>.
 
-Characters unmapped to CP-932, if C<CODEREF> is not specified, are deleted;
-if C<CODEREF> is specified,
-converted using C<CODEREF> from its Unicode codepoint (integer).
+Characters unmapped to Windows CP-932 are deleted,
+if C<CODEREF> is not specified;
+otherwise, converted using the C<CODEREF> from its Unicode codepoint (integer).
 
-For example, characters unmapped to CP-932 are 
+For example, characters unmapped to Windows CP-932 are 
 converted to numerical character references for HTML 4.01.
 
     utf16le_to_cp932(sub {sprintf "&#x%04x;", shift}, $utf16LE_string);
@@ -163,7 +165,7 @@ Tomoyuki SADAHIRO
   bqw10602@nifty.com
   http://homepage1.nifty.com/nomenclator/perl/
 
-  Copyright(C) 2001, SADAHIRO Tomoyuki. Japan. All rights reserved.
+  Copyright(C) 2001-2002, SADAHIRO Tomoyuki. Japan. All rights reserved.
 
 This program is free software; you can redistribute it and/or 
 modify it under the same terms as Perl itself.
